import { app } from "./app";
import { createServer } from "http";
import { WebSocket, WebSocketServer } from "ws";
import { attachEvents } from "./controllers/websocket-controller";
import { logger } from "./globals";

const PORT = process.env.PORT || 3000;

const server = createServer(app);

const wss = new WebSocketServer({ server });

wss.on('connection', (ws: WebSocket) => {
  logger.info('Websocket client connected');

  attachEvents(ws);

  ws.on('message', (message: string) => {
    logger.info(`Received message: ${message}`);
  });

  ws.on('close', () => {
    logger.info('Websocket client disconnected');
  });
});

server.listen(3000, () => {
  logger.info(`Server is running on http://localhost:${3000}`);
});